@@ -37,10 +37,8 @@ import locale
 import os
 import sys
 
-from colbert.common import DATE, DEBIT, CREDIT
 from colbert.livre_journal import (livre_journal_to_list, ecritures_to_livre_journal,
-                                   rechercher_ecriture, ajouter_ecriture)
-from colbert.livre_journal import ECRITURES
+                                   rechercher_ecriture, ajouter_ecriture, update_ecriture)
 from colbert.utils import DATE_FMT
 from optparse import OptionParser
 
@@ -53,6 +51,8 @@ def main():
         "examples:\n"
         "\t%prog search `lowercase expression'\n"
         "\t%prog add --date=21/12/2014 from-last-entry-like=cojean\n"
+        "\t%prog add --date=21/12/2014 from-last-entry-like=cojean -a 12.40\n"
+        "\t%prog add --date=21/12/2014 from-last-entry-like=cojean -a '12.40,10.00,2.40'\n"
     )
     version = "%prog 0.9"
     parser = OptionParser(usage=usage, version=version, description=__doc__)
@@ -68,14 +68,19 @@ def main():
     parser.add_option("-d", "--date", default=datetime.date.today().strftime(DATE_FMT),
                       help=u"Date de l'entrée à ajouter (par défaut: %default)")
     parser.add_option("-a", "--amounts",
-                      help=(u"Montant(s) des débits et crédits pour chaque compte. "
-                            u"Liste des montants entrées et des sorties ou montant "
-                            u"de l'entrée/sortie (si un seul compte de chaque côté). "
+                      help=(u"Liste des montants des entrées/sorties (séparés par une virgule) "
+                            u"ou montant de l'entrée/sortie (si un seul compte de chaque côté). "
                             u"Si non précisés, reprend les montants de l'écriture cible."))
     parser.add_option("-f", "--from-last-entry-like",
                       help=(u"Chemin vers le fichier Livre Journal. "
                             u"Par défaut : $%s" % LJ_PATH_ENV))
 
+    # Set encoding first.
+    encoding = locale.getpreferredencoding()
+    sys.stdout = codecs.getwriter(encoding)(sys.stdout)
+    for i, a in enumerate(sys.argv):
+        sys.argv[i] = unicode(a.decode(encoding))
+
     (options, args) = parser.parse_args()
 
     if not len(args) or args[0] not in ['search', 'add']:
@@ -96,8 +101,6 @@ def main():
         if not options.from_last_entry_like:
             parser.error("Vous devez passer une expression de recherche (option -f).")
 
-    sys.stdout = codecs.getwriter(locale.getpreferredencoding())(sys.stdout)
-
     if action == 'search':
         rechercher(expression, options.livre_journal_path)
     elif action == 'add':
@@ -123,16 +126,9 @@ def ajouter(options):
                    u"ressemblant à '%s'." % options.from_last_entry_like)
             return
 
-    # Construction de l'écriture
-    template_line[DATE] = options.date
-
-    if options.amounts:
-        # Version basique, un seul compte de chaque côté.
-        for e in template_line[ECRITURES]:
-            for op in (DEBIT, CREDIT):
-                if e[op] != '0.00':
-                    e[op] = options.amounts
+    amounts = options.amounts and options.amounts.split(",") or None
 
+    update_ecriture(template_line, options.date, amounts)
     ajouter_ecriture(template_line, options.livre_journal_path, lj_as_list,
                      options.output, options.dry_run, verbose=True)
 
